Tools to build Firewall Command for UFW from List of IPs
########################################################


`ip_to_ufw.py`
=============

Build UFW-Command from simple List of IPs

`ip_grep.py`
============

Analyse IP in a Logfile to build UFW Command

